import QtQuick 1.1
import com.nokia.meego 1.1

Page {
    id: mainPage
    orientationLock: PageOrientation.LockPortrait

    property int difficultyIndex;
    property string difficultImg;

    function openFile(file, param) {
        var component = Qt.createComponent(file)
        if (component.status === Component.Ready)
            pageStack.push(component, param);
        else
            console.log("Error loading component:", component.errorString());
    }

    Component.onCompleted: {
        mainPage.difficultyIndex = tSettings.getDifficulty();
        if (mainPage.difficultyIndex == 1) {
            mainPage.difficultImg = "images/medium.png";
        } else if (mainPage.difficultyIndex == 2) {
            mainPage.difficultImg = "images/hard.png";
        } else {
            mainPage.difficultImg = "images/easy.png"
        }
    }

    Image {
        id: banner
        source: "images/banner.png"
        anchors.top: parent.top
        anchors.topMargin: 80
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Image {
        id: paperBall
        source: "images/paper.png"
        width: 100
        height: 100
        anchors.left: parent.left
        anchors.leftMargin: 80
        anchors.top: banner.bottom
        anchors.topMargin: 80
        smooth: true
    }

    Image {
        id: bin
        source: "images/bin.png"
        width: 150
        fillMode: Image.PreserveAspectFit
        anchors.left: parent.left
        anchors.leftMargin: 30
        anchors.top: paperBall.bottom
        anchors.topMargin: 50
        smooth: true
    }

    Image {
        id: difficultyBtn
        source: mainPage.difficultImg
        anchors.left: playBtn.left
        anchors.top: banner.bottom
        anchors.topMargin: 90
        cache: false

        MouseArea {
            anchors.fill: parent
            onClicked: difficultySelectionDlg.open();
        }
    }

    Image {
        id: playBtn
        source: "images/play.png"
        anchors.left: bin.right
        anchors.leftMargin: 90
        anchors.top: difficultyBtn.bottom
        anchors.topMargin: 40

        MouseArea {
            anchors.fill: parent
            onClicked: {
                screen.allowSwipe = false;
                openFile("PaperToss.qml", {level: mainPage.difficultyIndex});
            }
        }
    }

    Image {
        id: aboutBtn
        source: "images/about.png"
        anchors.left: playBtn.left
        anchors.top: playBtn.bottom
        anchors.topMargin: 40

        MouseArea {
            anchors.fill: parent
            onClicked: {
                openFile("AboutPage.qml");
            }
        }
    }

    Image {
        id: quitBtn
        source: "images/quit.png"
        anchors.left: playBtn.left
        anchors.top: aboutBtn.bottom
        anchors.topMargin: 40

        MouseArea {
            anchors.fill: parent
            onClicked: Qt.quit();
        }
    }

    SelectionDialog {
        id: difficultySelectionDlg
        titleText: "Select Difficulty"
        selectedIndex: mainPage.difficultyIndex
        model: ListModel {
            ListElement { name: "Easy" }
            ListElement { name: "Medium" }
            ListElement { name: "Hard" }
        }

        onSelectedIndexChanged: {
            mainPage.difficultyIndex = difficultySelectionDlg.selectedIndex
            tSettings.setDifficulty(mainPage.difficultyIndex);
            if (mainPage.difficultyIndex == 1) {
                mainPage.difficultImg = "images/medium.png";
            } else if (mainPage.difficultyIndex == 2) {
                mainPage.difficultImg = "images/hard.png";
            } else {
                mainPage.difficultImg = "images/easy.png"
            }
        }
    }
}
